summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/chatview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/kopete/chatwindow/chatview.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/kopete/chatwindow/chatview.h')
-rw-r--r--kopete/kopete/chatwindow/chatview.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/kopete/kopete/chatwindow/chatview.h b/kopete/kopete/chatwindow/chatview.h
index 1a89af99..039918dd 100644
--- a/kopete/kopete/chatwindow/chatview.h
+++ b/kopete/kopete/chatwindow/chatview.h
@@ -54,8 +54,9 @@ namespace Kopete
class ChatView : public KDockMainWindow, public KopeteView
{
Q_OBJECT
+ TQ_OBJECT
public:
- ChatView( Kopete::ChatSession *manager, ChatWindowPlugin *parent, const char *name = 0 );
+ ChatView( Kopete::ChatSession *manager, ChatWindowPlugin *tqparent, const char *name = 0 );
~ChatView();
/** the state of our chat */
@@ -104,10 +105,10 @@ public:
void setCaption( const TQString &text, bool modified );
/**
* Changes the pointer to the chat window. Used to re-parent the view
* @param parent The new chat window
*/
- void setMainWindow( KopeteChatWindow* parent );
+ void setMainWindow( KopeteChatWindow* tqparent );
/**
* Returns the message currently in the edit area
@@ -119,7 +120,7 @@ public:
/**
* Sets the current message in the chat window
* @param parent The new chat window
*
* Reimplemented from KopeteView
*/
@@ -300,7 +301,7 @@ signals:
void canSendChanged(bool);
/**
* Emitted when we re-parent ourselves with a new window
*/
void windowCreated();
@@ -381,7 +382,7 @@ private:
// position and visibility of the chat member list
KDockWidget::DockPosition membersDockPosition;
enum MembersListPolicy { Smart = 0, Visible = 1, Hidden = 2 };
- MembersListPolicy membersStatus;
+ MembersListPolicy memberstqStatus;
// miscellany
TQPtrDict<TQTimer> m_remoteTypingMap;
@@ -411,7 +412,7 @@ private:
class ChatWindowPlugin : public Kopete::ViewPlugin
{
public:
- ChatWindowPlugin(TQObject *parent, const char *name, const TQStringList &args);
+ ChatWindowPlugin(TQObject *tqparent, const char *name, const TQStringList &args);
KopeteView* createView( Kopete::ChatSession *manager );
};
@@ -104,10 +105,10 @@ public:
void setCaption( const TQString &text, bool modified );
/**
- * Changes the pointer to the chat window. Used to re-parent the view
- * @param parent The new chat window
+ * Changes the pointer to the chat window. Used to re-tqparent the view
+ * @param tqparent The new chat window
*/
@@ -119,7 +120,7 @@ public:
/**
* Sets the current message in the chat window
- * @param parent The new chat window
+ * @param tqparent The new chat window
*
* Reimplemented from KopeteView
@@ -300,7 +301,7 @@ signals:
void canSendChanged(bool);
/**
- * Emitted when we re-parent ourselves with a new window
+ * Emitted when we re-tqparent ourselves with a new window
*/
void windowCreated();